Coverage for arrakis/constants.py: 100.0%

1# Copyright (c) 2022, California Institute of Technology and contributors

2#

3# You should have received a copy of the licensing terms for this

4# software included in the file "LICENSE" located in the top-level

5# directory of this package. If you did not, you can view a copy at

6# https://git.ligo.org/ngdd/arrakis-python/-/raw/main/LICENSE

7

8 from datetime import timedelta

9

10 import numpy

11

12 DEFAULT_ARRAKIS_SERVER = "grpc://0.0.0.0:31206"

13

14 DEFAULT_MATCH = ".*"

15 DEFAULT_TIMEOUT = timedelta(seconds=2)

16 DEFAULT_QUEUE_TIMEOUT = timedelta(milliseconds=125)

17

18 MIN_SAMPLE_RATE = 0

19 MAX_SAMPLE_RATE = numpy.iinfo(numpy.uint32).max